/*
 * stock.h
 *
 *
 * Authors:
 *  Richard Hult <rhult@hem.passagen.se>
 *  Ricardo Markiewicz <rmarkie@fi.uba.ar>
 *  Andres de Barbara <adebarbara@fi.uba.ar>
 *
 * Web page: http://arrakis.lug.fi.uba.ar/
 *
 * Copyright (C) 1999-2001  Richard Hult
 * Copyright (C) 2003,2004  LUGFI
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __STOCK_H
#define __STOCK_H

/* Stock names */

#define STOCK_PIXMAP_SIM_SETTINGS "OREGANO_stock_sim_settings"
#define STOCK_PIXMAP_ROTATE "OREGANO_stock_rotate"
#define STOCK_PIXMAP_ZOOM_IN "OREGANO_stock_zoom_in"
#define STOCK_PIXMAP_ZOOM_OUT "OREGANO_stock_zoom_out"
#define STOCK_PIXMAP_PLOT "OREGANO_stock_plot"
#define STOCK_PIXMAP_PART_BROWSER "OREGANO_stock_part_browser"
#define STOCK_PIXMAP_GRID "OREGANO_stock_grid"
#define STOCK_PIXMAP_ARROW "OREGANO_stock_arrow"
#define STOCK_PIXMAP_TEXT "OREGANO_stock_text"
#define STOCK_PIXMAP_WIRE "OREGANO_stock_wire"
#define STOCK_PIXMAP_VOLTMETER "OREGANO_stock_voltmeter"
#define STOCK_PIXMAP_V_CLAMP "OREGANO_stock_v_clamp"
#define STOCK_PIXMAP_ZOOM_PAN "OREGANO_stock_zoom_pan"
#define STOCK_PIXMAP_ZOOM_REGION "OREGANO_stock_zoom_region"

void stock_init (void);

#endif
